==> jc-1.4.0.tar.gz: java/security/cert/PolicyQualifierInfo.h <==
// public final class java.security.cert.PolicyQualifierInfo

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a58f256e222bd3b3 java_security_cert_PolicyQualifierInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_PolicyQualifierInfo_H_
#define _JC_java_security_cert_PolicyQualifierInfo_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_gnu_java_security_der_DERValue$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_cert_PolicyQualifierInfo$sub_refs	_jc_java_security_cert_PolicyQualifierInfo$sub_refs;
typedef struct _jc_java_security_cert_PolicyQualifierInfo$sub_nonrefs	_jc_java_security_cert_PolicyQualifierInfo$sub_nonrefs;
typedef struct _jc_java_security_cert_PolicyQualifierInfo$refs	_jc_java_security_cert_PolicyQualifierInfo$refs;
typedef struct _jc_java_security_cert_PolicyQualifierInfo$nonrefs	_jc_java_security_cert_PolicyQualifierInfo$nonrefs;
typedef struct _jc_java_security_cert_PolicyQualifierInfo$object	_jc_java_security_cert_PolicyQualifierInfo$object;

typedef const struct _jc_java_security_cert_PolicyQualifierInfo$vmethods	_jc_java_security_cert_PolicyQualifierInfo$vmethods;
typedef const struct _jc_java_security_cert_PolicyQualifierInfo$vtable	_jc_java_security_cert_PolicyQualifierInfo$vtable;
typedef const struct _jc_java_security_cert_PolicyQualifierInfo$vtype	_jc_java_security_cert_PolicyQualifierInfo$vtype;

// Constructors
extern void _jc_java_security_cert_PolicyQualifierInfo$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *, struct _jc_byte_array *);

// Virtual methods
extern _jc_byte_array *_jc_java_security_cert_PolicyQualifierInfo$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *);
extern _jc_byte_array *_jc_java_security_cert_PolicyQualifierInfo$method$getPolicyQualifier$cb317b69e884fe67(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_cert_PolicyQualifierInfo$method$getPolicyQualifierId$c977b859dacf951a(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_cert_PolicyQualifierInfo$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_PolicyQualifierInfo$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_java_security_cert_PolicyQualifierInfo$method_info$getPolicyQualifier$cb317b69e884fe67;
extern _jc_method _jc_java_security_cert_PolicyQualifierInfo$method_info$getPolicyQualifierId$c977b859dacf951a;
extern _jc_method _jc_java_security_cert_PolicyQualifierInfo$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_PolicyQualifierInfo$vmethods {
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *);
	_jc_byte_array	*(*getPolicyQualifier$cb317b69e884fe67)(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *);
	struct _jc_java_lang_String$object	*(*getPolicyQualifierId$c977b859dacf951a)(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *);
};

// Vtable
struct _jc_java_security_cert_PolicyQualifierInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_PolicyQualifierInfo$vmethods	java_security_cert_PolicyQualifierInfo;
};

// Vtype
struct _jc_java_security_cert_PolicyQualifierInfo$vtype {
	_jc_type			type;
	_jc_java_security_cert_PolicyQualifierInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_PolicyQualifierInfo$sub_refs {
	struct _jc_gnu_java_security_OID$object	*oid;
	_jc_byte_array	*encoded;
	struct _jc_gnu_java_security_der_DERValue$object	*qualifier;
};

// Reference instance fields (object)
struct _jc_java_security_cert_PolicyQualifierInfo$refs {
    _jc_java_security_cert_PolicyQualifierInfo$sub_refs	java_security_cert_PolicyQualifierInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_PolicyQualifierInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_PolicyQualifierInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_PolicyQualifierInfo$sub_nonrefs	java_security_cert_PolicyQualifierInfo;
};

// Object instance structure
struct _jc_java_security_cert_PolicyQualifierInfo$object {
	_jc_java_security_cert_PolicyQualifierInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_PolicyQualifierInfo$vtype	*vtype;
	_jc_java_security_cert_PolicyQualifierInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_PolicyQualifierInfo$vtype _jc_java_security_cert_PolicyQualifierInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_PolicyQualifierInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_PolicyQualifierInfo$class_object;

#endif	/* _JC_java_security_cert_PolicyQualifierInfo_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/PolicyQualifierInfo.h <==
// public final class java.security.cert.PolicyQualifierInfo

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a58f256e222bd3b3 java_security_cert_PolicyQualifierInfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_PolicyQualifierInfo_H_
#define _JC_java_security_cert_PolicyQualifierInfo_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_gnu_java_security_der_DERValue$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_cert_PolicyQualifierInfo$sub_refs	_jc_java_security_cert_PolicyQualifierInfo$sub_refs;
typedef struct _jc_java_security_cert_PolicyQualifierInfo$sub_nonrefs	_jc_java_security_cert_PolicyQualifierInfo$sub_nonrefs;
typedef struct _jc_java_security_cert_PolicyQualifierInfo$refs	_jc_java_security_cert_PolicyQualifierInfo$refs;
typedef struct _jc_java_security_cert_PolicyQualifierInfo$nonrefs	_jc_java_security_cert_PolicyQualifierInfo$nonrefs;
typedef struct _jc_java_security_cert_PolicyQualifierInfo$object	_jc_java_security_cert_PolicyQualifierInfo$object;

typedef const struct _jc_java_security_cert_PolicyQualifierInfo$vmethods	_jc_java_security_cert_PolicyQualifierInfo$vmethods;
typedef const struct _jc_java_security_cert_PolicyQualifierInfo$vtable	_jc_java_security_cert_PolicyQualifierInfo$vtable;
typedef const struct _jc_java_security_cert_PolicyQualifierInfo$vtype	_jc_java_security_cert_PolicyQualifierInfo$vtype;

// Constructors
extern void _jc_java_security_cert_PolicyQualifierInfo$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_java_security_cert_PolicyQualifierInfo$method$getEncoded$eaf136136217eb89(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_java_security_cert_PolicyQualifierInfo$method$getPolicyQualifier$cb317b69e884fe67(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_cert_PolicyQualifierInfo$method$getPolicyQualifierId$c977b859dacf951a(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_cert_PolicyQualifierInfo$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_PolicyQualifierInfo$method_info$getEncoded$eaf136136217eb89;
extern _jc_method _jc_java_security_cert_PolicyQualifierInfo$method_info$getPolicyQualifier$cb317b69e884fe67;
extern _jc_method _jc_java_security_cert_PolicyQualifierInfo$method_info$getPolicyQualifierId$c977b859dacf951a;
extern _jc_method _jc_java_security_cert_PolicyQualifierInfo$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_PolicyQualifierInfo$vmethods {
	_jc_byte_array	*(*getEncoded$eaf136136217eb89)(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getPolicyQualifier$cb317b69e884fe67)(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPolicyQualifierId$c977b859dacf951a)(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_PolicyQualifierInfo$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_PolicyQualifierInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_PolicyQualifierInfo$vmethods	java_security_cert_PolicyQualifierInfo;
};

// Vtype
struct _jc_java_security_cert_PolicyQualifierInfo$vtype {
	_jc_type			type;
	_jc_java_security_cert_PolicyQualifierInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_PolicyQualifierInfo$sub_refs {
	struct _jc_gnu_java_security_OID$object	*oid;
	_jc_byte_array	*encoded;
	struct _jc_gnu_java_security_der_DERValue$object	*qualifier;
};

// Reference instance fields (object)
struct _jc_java_security_cert_PolicyQualifierInfo$refs {
    _jc_java_security_cert_PolicyQualifierInfo$sub_refs	java_security_cert_PolicyQualifierInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_PolicyQualifierInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_PolicyQualifierInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_PolicyQualifierInfo$sub_nonrefs	java_security_cert_PolicyQualifierInfo;
};

// Object instance structure
struct _jc_java_security_cert_PolicyQualifierInfo$object {
	_jc_java_security_cert_PolicyQualifierInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_PolicyQualifierInfo$vtype	*vtype;
	_jc_java_security_cert_PolicyQualifierInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_PolicyQualifierInfo$vtype _jc_java_security_cert_PolicyQualifierInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_PolicyQualifierInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_PolicyQualifierInfo$class_object;

#endif	/* _JC_java_security_cert_PolicyQualifierInfo_H_ */
